<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1405"/>
        <source>%1 is released under %2</source>
        <translation>%1 wurde unter %2 veröffentlicht.</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="869"/>
        <source>Black</source>
        <translation>Schwarz</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="872"/>
        <source>White</source>
        <translation>Weiß</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="875"/>
        <source>Dark Gray</source>
        <translation>Dunkelgrau</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="878"/>
        <source>Gray</source>
        <translation>Grau</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="881"/>
        <source>Light Gray</source>
        <translation>Hellgrau</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="884"/>
        <source>Red</source>
        <translation>Rot</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="887"/>
        <source>Green</source>
        <translation>Grün</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="890"/>
        <source>Blue</source>
        <translation>Blau</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="893"/>
        <source>Cyan</source>
        <translation>Cyan</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="896"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="899"/>
        <source>Yellow</source>
        <translation>Gelb</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="902"/>
        <source>Dark Red</source>
        <translation>Dunkelrot</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="905"/>
        <source>Dark Green</source>
        <translation>Dunkelgrün</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="908"/>
        <source>Dark Blue</source>
        <translation>Dunkelblau</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="911"/>
        <source>Dark Cyan</source>
        <translation>Dunkles Cyan</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="914"/>
        <source>Dark Magenta</source>
        <translation>Dunkles Magenta</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="917"/>
        <source>Dark Yellow</source>
        <translation>Dunkelgelb</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="29"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="30"/>
        <source>Confirm</source>
        <translation>Bestätigen</translation>
    </message>
</context>
<context>
    <name>DKeySequenceEdit</name>
    <message>
        <location filename="../widgets/dkeysequenceedit.cpp" line="97"/>
        <source>Enter a new shortcut</source>
        <translation>Geben Sie ein neues Tastenkürzel ein</translation>
    </message>
</context>
<context>
    <name>DLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="593"/>
        <source>Stop reading</source>
        <translation>Lesen beenden</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="595"/>
        <source>Text to Speech</source>
        <translation>Text zu Sprache</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="618"/>
        <source>Translate</source>
        <translation>Übersetzen</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="640"/>
        <source>Speech To Text</source>
        <translation>Sprache zu Text</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewDialogPrivate</name>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="278"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1268"/>
        <source>Advanced</source>
        <translation>Fortgeschritten</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="301"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="302"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1647"/>
        <source>Print</source>
        <comment>button</comment>
        <translation>Drucken</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="318"/>
        <source>Basic</source>
        <translation>Basis</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="334"/>
        <source>Printer</source>
        <translation>Drucker</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="350"/>
        <source>Copies</source>
        <translation>Kopien</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="372"/>
        <source>Page range</source>
        <translation>Seitenumfang</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="375"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="376"/>
        <source>Current page</source>
        <translation>Aktuelle Seite</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="377"/>
        <source>Select pages</source>
        <translation>Seiten auswählen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="397"/>
        <source>Orientation</source>
        <translation>Ausrichtung</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="422"/>
        <source>Portrait</source>
        <translation>Hochformat</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="432"/>
        <source>Landscape</source>
        <translation>Querformat</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="460"/>
        <source>Pages</source>
        <translation>Seiten</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="472"/>
        <source>Color mode</source>
        <translation>Farbmodus</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="475"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1583"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1663"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1679"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1694"/>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="475"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1670"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1682"/>
        <source>Grayscale</source>
        <translation>Graustufen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="487"/>
        <source>Margins</source>
        <translation>Ränder</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Narrow (mm)</source>
        <translation>Schmal (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Normal (mm)</source>
        <translation>Normal (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Moderate (mm)</source>
        <translation>Moderat (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Customize (mm)</source>
        <translation>Anpassen (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="500"/>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="503"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="506"/>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="509"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="556"/>
        <source>Scaling</source>
        <translation>Skalierung</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="573"/>
        <source>Actual size</source>
        <translation>Tatsächliche Größe</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="582"/>
        <source>Scale</source>
        <translation>Skala</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="613"/>
        <source>Paper</source>
        <translation>Papier</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="626"/>
        <source>Paper size</source>
        <translation>Papiergröße</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="641"/>
        <source>Print Layout</source>
        <translation>Druckanordnung</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="655"/>
        <source>Duplex</source>
        <translation>Duplex</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="668"/>
        <source>N-up printing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>2 pages/sheet, 1×2</source>
        <translation>2 Seiten/Blatt, 1×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>4 pages/sheet, 2×2</source>
        <translation>4 Seiten/Blatt, 2×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>6 pages/sheet, 2×3</source>
        <translation>6 Seiten/Blatt, 2×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>9 pages/sheet, 3×3</source>
        <translation>9 Seiten/Blatt, 3×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>16 pages/sheet, 4×4</source>
        <translation>16 Seiten/Blatt, 4×4</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="683"/>
        <source>Layout direction</source>
        <translation>Richtung der Anordnung</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="727"/>
        <source>Page Order</source>
        <translation>Seitenreihenfolge</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="740"/>
        <source>Collate pages</source>
        <translation>Seiten zusammenstellen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="746"/>
        <source>Print pages in order</source>
        <translation>Seiten der Reihe nach drucken</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
        <source>Front to back</source>
        <translation>Von vorne nach hinten</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
        <source>Back to front</source>
        <translation>Von hinten nach vorne</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="774"/>
        <source>Watermark</source>
        <translation>Wasserzeichen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="788"/>
        <source>Add watermark</source>
        <translation>Wasserzeichen hinzufügen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="834"/>
        <source>Text watermark</source>
        <translation>Textwasserzeichen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Confidential</source>
        <translation>Vertraulich</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Draft</source>
        <translation>Entwurf</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Sample</source>
        <translation>Muster</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Custom</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="847"/>
        <source>Input your text</source>
        <translation>Geben Sie Ihren Text ein</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="872"/>
        <source>Picture watermark</source>
        <translation>Bildwasserzeichen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="896"/>
        <source>Layout</source>
        <translation>Anordnung</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="899"/>
        <source>Tile</source>
        <translation>Kachel</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="899"/>
        <source>Center</source>
        <translation>Mitte</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="912"/>
        <source>Angle</source>
        <translation>Winkel</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="931"/>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="955"/>
        <source>Transparency</source>
        <translation>Transparenz</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1013"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2283"/>
        <source>Print to PDF</source>
        <translation>In PDF drucken</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1014"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2282"/>
        <source>Save as Image</source>
        <translation>Als Bild speichern</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1264"/>
        <source>Collapse</source>
        <translation>Einklappen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1359"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1368"/>
        <source>Flip on short edge</source>
        <translation>Auf der kurzen Kante spiegeln</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1298"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1363"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1367"/>
        <source>Flip on long edge</source>
        <translation>Auf der langen Kante spiegeln</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1461"/>
        <source>Input page numbers please</source>
        <translation>Bitte Seitenzahlen eingeben</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1464"/>
        <source>Maximum page number reached</source>
        <translation>Maximale Seitenzahl erreicht</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1467"/>
        <source>Input English comma please</source>
        <translation>Bitte englisches Komma eingeben</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1470"/>
        <source>Input page numbers like this: 1,3,5-7,11-15,18,21</source>
        <translation>Seitenzahlen wie folgt eingeben: 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1700"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2312"/>
        <source>*.pdf</source>
        <translation>*.pdf</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1770"/>
        <source>For example, 1,3,5-7,11-15,18,21</source>
        <translation>Zum Beispiel 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2312"/>
        <source>Save as PDF</source>
        <translation>Als PDF speichern</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2351"/>
        <source>Save as image</source>
        <translation>Als Bild speichern</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2353"/>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewWidget</name>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1590"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1593"/>
        <source>Confidential</source>
        <translation>Vertraulich</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1608"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1611"/>
        <source>Draft</source>
        <translation>Entwurf</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1626"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1629"/>
        <source>Sample</source>
        <translation>Muster</translation>
    </message>
</context>
<context>
    <name>DSearchEdit</name>
    <message>
        <location filename="../widgets/dsearchedit.cpp" line="286"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>DSettingsDialog</name>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="66"/>
        <source>Replace</source>
        <translation>Ersetzen</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="68"/>
        <source>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</source>
        <translation>Dieses Tastenkürzel steht in Konflikt mit %1. Klicken Sie auf &quot;Hinzufügen&quot;, damit dieses Tastenkürzel sofort wirksam wird</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="18"/>
        <source>Please input a new shortcut</source>
        <translation>Bitte geben Sie ein neues Tastenkürzel ein</translation>
    </message>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="89"/>
        <source>None</source>
        <translation>Keine</translation>
    </message>
</context>
<context>
    <name>DTextEdit</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="202"/>
        <source>Stop reading</source>
        <translation>Lesen beenden</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="204"/>
        <source>Text to Speech</source>
        <translation>Text zu Sprache</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="227"/>
        <source>Translate</source>
        <translation>Übersetzen</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="249"/>
        <source>Speech To Text</source>
        <translation>Sprache zu Text</translation>
    </message>
</context>
<context>
    <name>DToolbarEditPanel</name>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="884"/>
        <source>Default toolset</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="915"/>
        <source>Drag your favorite items into the toolbar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="916"/>
        <source>Drag below items into the toolbar to restore defaults</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="921"/>
        <source>Confirm</source>
        <translation>Bestätigen</translation>
    </message>
</context>
<context>
    <name>PickColorWidget</name>
    <message>
        <location filename="../widgets/dprintpickcolorwidget.cpp" line="94"/>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="526"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopieren</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="529"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Ausschneiden</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="534"/>
        <source>Select All</source>
        <translation>Alles auswählen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/dsimplelistview.cpp" line="1347"/>
        <source>No search result</source>
        <translation>Keine Suchergebnisse</translation>
    </message>
    <message>
        <location filename="../widgets/private/settings/content.cpp" line="330"/>
        <source>Restore Defaults</source>
        <translation>Standardeinstellungen wiederherstellen</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="109"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="111"/>
        <source>Features</source>
        <translation>Funktionen</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="123"/>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="125"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="127"/>
        <source>Acknowledgements</source>
        <translation>Anerkennungen</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="129"/>
        <location filename="../widgets/daboutdialog.cpp" line="138"/>
        <source>Sincerely appreciate the open-source software used.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="140"/>
        <source>open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dfeaturedisplaydialog.cpp" line="151"/>
        <source>Continue</source>
        <translation>Fortsetzen</translation>
    </message>
    <message>
        <location filename="../widgets/dfeaturedisplaydialog.cpp" line="175"/>
        <source>Learn More</source>
        <translation>Mehr erfahren</translation>
    </message>
    <message>
        <location filename="../widgets/dlicensedialog.cpp" line="141"/>
        <source>Open-Source Software</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QWidgetTextControl</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="194"/>
        <source>Select All</source>
        <translation>Alles auswählen</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../widgets/private/settings/shortcutedit.cpp" line="104"/>
        <source>Please enter a new shortcut</source>
        <translation>Bitte geben Sie ein neues Tastenkürzel ein</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="634"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="636"/>
        <source>Light Theme</source>
        <translation>Helles Thema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="637"/>
        <source>Dark Theme</source>
        <translation>Dunkles Thema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="638"/>
        <source>System Theme</source>
        <translation>Systemthema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="668"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="676"/>
        <source>Feedback</source>
        <translation>Rückmeldung</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="683"/>
        <source>Custom toolbar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="691"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="698"/>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
</context>
</TS>